@@ -9,7 +9,7 @@ use constant _share_dir => File::ShareDir::dist_dir('Alien-bz2');
 use constant _alien_bz2012 => 1;
 
 # ABSTRACT: Build and make available bz2
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 my $cf = 'Alien::bz2::ConfigData';
 
@@ -106,7 +106,7 @@ Alien::bz2 - Build and make available bz2
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -157,12 +157,16 @@ be found, this distribution will use the bz2 that comes with your
 operating system, otherwise it will download it from the Internet, build
 and install it.
 
-If you set the environment variable ALIEN_BZ2 to 'share', this
+If you set the environment variable C<ALIEN_BZ2> to 'share', this
 distribution will ignore any system bz2 found, and build from
 source instead.  This may be desirable if your operating system comes
 with a very old version of bz2 and an upgrade path for the 
 system bz2 is not possible.
 
+This distribution also honors the C<ALIEN_FORCE> environment variable used
+by L<Alien::Base>.  Setting C<ALIEN_FORCE> has the same effect as setting
+C<ALIEN_BZ2> to 'share'.
+
 =head1 METHODS
 
 =head2 cflags
